@@ -23,11 +23,11 @@ class OwnerOnly(utils.Cog, command_attrs={'hidden': True, 'add_slash_command': F
 
     def __init__(self, bot: utils.Bot):
         super().__init__(bot)
-        if bot.config.get("redis", {}).get("enabled"):
+        if self.bot.config.get("redis", {}).get("enabled"):
             self.redis_ev_listener.start()
 
     def cog_unload(self):
-        if bot.config.get("redis", {}).get("enabled"):
+        if self.bot.config.get("redis", {}).get("enabled"):
             self.redis_ev_listener.stop()
 
     @utils.redis_channel_handler("RunRedisEval")
@@ -164,9 +164,9 @@ class OwnerOnly(utils.Cog, command_attrs={'hidden': True, 'add_slash_command': F
 
         # And send our data
         try:
-            await sendable.send(**payload)
+            await sendable.send(**payload, embeddify=False)
         except discord.HTTPException as e:
-            return await ctx.send(f"I couldn't send that message - `{e}`")
+            return await ctx.send(f"I couldn't send that message - `{e}`", embeddify=False)
         await ctx.okay()
 
     def _cleanup_code(self, content):
@@ -216,8 +216,9 @@ class OwnerOnly(utils.Cog, command_attrs={'hidden': True, 'add_slash_command': F
             'guild': ctx.guild,
             'message': ctx.message,
             'self': self,
+            'vbu': utils,
         }
-        env.update(globals())
+        # env.update(globals())
 
         # See if the user attached a file (alix was here)
         if ctx.message.attachments:
