@@ -12,7 +12,7 @@ class PresenceAutoUpdater(utils.Cog):
     TWITCH_SEARCH_URL = "https://api.twitch.tv/helix/streams"
     TWITCH_USERNAME_URL = "https://api.twitch.tv/helix/users"
 
-    def __init__(self, bot:utils.Bot):
+    def __init__(self, bot: utils.Bot):
         super().__init__(bot)
         self.presence_auto_update_loop.start()
         self.presence_before = None
@@ -20,11 +20,12 @@ class PresenceAutoUpdater(utils.Cog):
         self._refresh_token_task = None
         self.twitch_user_ids = {}  # str: str
         self._user_streaming_status = None
+        self._config_embed_footers = None
 
     def cog_unload(self):
         self.presence_auto_update_loop.cancel()
 
-    async def get_app_token(self, force_refresh:bool=False) -> str:
+    async def get_app_token(self, force_refresh: bool = False) -> str:
         """
         Get a valid app token from Twitch
         """
@@ -68,9 +69,9 @@ class PresenceAutoUpdater(utils.Cog):
         # And return the app token
         return self._twitch_app_token
 
-    async def get_twitch_user_id(self, username:str) -> str:
+    async def get_twitch_user_id(self, username: str) -> str:
         """
-        Get the user ID for a given Twitch username
+        Get the user ID for a given Twitch username.
         """
 
         if username in self.twitch_user_ids:
@@ -86,12 +87,12 @@ class PresenceAutoUpdater(utils.Cog):
         self.logger.debug(f"GET {self.TWITCH_USERNAME_URL} returned {data}")
         try:
             self.twitch_user_ids[username] = data["data"][0]["id"]
-        except KeyError as e:
+        except KeyError:
             self.logger.error(f"Failed to get Twitch username from search - {data.get('message') or 'no error message'}")
-            raise e
-        except IndexError as e:
+            raise
+        except IndexError:
             self.logger.error("Invalid Twitch username set in config")
-            raise e
+            raise
         return self.twitch_user_ids[username]
 
     @tasks.loop(seconds=30)
@@ -153,11 +154,18 @@ class PresenceAutoUpdater(utils.Cog):
             # Alright let's set
             await self.bot.set_default_presence()
             self._user_streaming_status = None
+            self.bot.config.setdefault('embed', dict())['footer'] = self._config_embed_footers
+            self._config_embed_footers = None
             return
 
         # Let's set a new streaming activity
         else:
 
+            # Let's change the default embed footer
+            if self._config_embed_footers is None:
+                self._config_embed_footers = self.bot.config.get('embed', dict()).get('footer', list()).copy()
+                self.bot.config.setdefault('embed', dict())['footer'] = [{"text": "Currently live on Twitch!", "amount": 1}]
+
             # We currently aren't streaming
             if self._user_streaming_status is None:
                 await self.bot.change_presence(activity=status_to_set)
@@ -176,6 +184,6 @@ class PresenceAutoUpdater(utils.Cog):
         await asyncio.sleep(1)  # Let's sleep here so we don't override our on_ready's set default presence
 
 
-def setup(bot:utils.Bot):
+def setup(bot: utils.Bot):
     x = PresenceAutoUpdater(bot)
     bot.add_cog(x)
